
#include <SPI.h>
#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>
#include <GY_61.h>
#include <RTClib.h>
#define OLED_RESET 4

Adafruit_SSD1306 display(OLED_RESET);
RTC_DS3231 rtc;
GY_61 accel;

char daysOfTheWeek[7][12] = {"Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"};
char monthsOfTheYear[13][4] = {"Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"};
int hours;
int ledPin = 4;
int ptich;


void setup() {
  Serial.begin(9600); 

  //Setup OLED
  display.begin(SSD1306_SWITCHCAPVCC, 0x3C);  // initialize with the I2C addr 0x3D (for the 128x64)
  display.display(); //Show image buffer on the display hardware
  delay(2000);
  display.clearDisplay(); //Clear the buffer.

  //Setup RTC and adjust time
  rtc.adjust(DateTime(F(__DATE__), F(__TIME__))); // Sets time based on computer
//  rtc.adjust(DateTime(2020, 3, 23, 17, 28, 30)); // Sets explicit date and time: March 23, 2020 at 5:28:30pm

  //Setup for Accelerometer 
  accel = GY_61(A0, A1, A2); //sets which arduino pins used for data GY_61(x, y, z)

  //Setup pin for LED
  pinMode(ledPin, OUTPUT);
}


void loop () {

  // CLOCK //
  if ((accel.readx() <= -8) && (300 < accel.ready() < 370)) //Accelerometer boundries for clock position
  {
    showclock:
    digitalWrite(ledPin, LOW); //LED off
    display.clearDisplay(); //initialize display
    DateTime now = rtc.now(); //get time
    //display time in 12hr format
    if (now.hour() > 12)
    {
      hours = now.hour() - 12;
    }
    else {
      hours = now.hour();
    }
    //set display parameters and formatting
    display.setRotation(4);
    display.setTextSize(4);
    display.setTextColor(WHITE);
    display.setCursor(0, 0);
    if (now.hour() < 10)
    {
      display.print(" "); // add a space before hour if single digit
    }
    display.print(hours, DEC);
    display.print(":");
    if (now.minute() < 10) 
    {
      display.print('0'); //add a 0 before single digit
    }
    display.print(now.minute(), DEC);
    display.display();
    delay(1000);
    display.clearDisplay();//clear display 
  }


  // DATE //
  if ((-8 < accel.readx() < 8) && (accel.ready() <= 300)) //Accelerometer boundries for date position
  {
    showdate:
    digitalWrite(ledPin, LOW); //LED off
    DateTime now = rtc.now(); //get time
    //set display parameters and formatting
    display.setTextSize(1);
    display.setTextColor(WHITE);
    display.setCursor(8, 15);
    testdrawrect();
    display.setRotation(3);
    display.print(monthsOfTheYear[now.month() - 1]); //display month
    display.print(" ");
    display.setCursor(5, 70);
    display.setTextSize(2);
    display.setTextColor(WHITE);
    if (now.day() < 10)
    {
      display.print("0"); //add a 0 before single digit
    }
    display.print(now.day(), DEC); //display day
    display.display();
  }


  // TIMER //
  if ((-8 < accel.readx() < 8) && (accel.ready() > 370)) //Accelerometer boundries for Timer position
  {
    showtimer:
    digitalWrite(ledPin, LOW); //LED off
    display.clearDisplay(); //clear display
    //set display paramters and formatting
    display.setTextSize(2);
    display.setTextColor(WHITE);
    display.setCursor(0, 0);
    display.setRotation(1);
    for (int m = 14; m >= 0; m = m - 1) //For loop for countdown timer (adjust m = 14 for different time)
    {
      for (int s = 59; s >= 0; s = s - 1)
      { 
        //exit timer for position changes
        if ((accel.readx() <= -8) && (300 < accel.ready() < 370))
        {
          goto showclock; 
        }
        if ((-8 < accel.readx() < 8) && (accel.ready() <= 300))
        {
          goto showdate;
        }
        if ((accel.readx() >= 8) && (300 < accel.ready() < 370))
        {
          goto showblank;
        }
        if (accel.readz() <= 275)
        {
          goto showled;
        }
        if (m < 10)
        {
          display.setCursor(4, 30);
          display.print('0'); //add 0 infront of single digit
          display.print(m);
        }
        else
        {
          display.setCursor(4, 30);
          display.print(m);
        }
        display.setCursor(10, 60);
        display.print(":");
        if (s < 10)
        {
          display.setCursor(4, 90);
          display.print('0'); //add 0 infront of single digit
          display.print(s);
        }
        else
        {
          display.setCursor(4, 90);
          display.print(s);
        }
        display.display();
        delay(1000);
        display.clearDisplay();
        
      }
    }
    display.display();
    display.clearDisplay();
    //Set flashing screen when timer is up
    for (int i = 0; i <= 200; i++)
    {
      tone(8, 2100, 200); //Turn on Piezo buzzer tone(pin, frequency, duration)
      display.invertDisplay(true);
      delay(250);
      display.invertDisplay(false);
      delay(250);
      display.clearDisplay();
      if ((accel.readx() <= -8) && (300 < accel.ready() < 370)) //Turn off Piezo buzzer only when back to CLOCK position 
      {
        goto showclock; 
      }
    }
  }


  // OFF //
  if ((accel.readx() >= 8) && (300 < accel.ready() < 370)) //Accelerometer boundries for OFF position
  {
    showblank:
    display.display();
    display.clearDisplay();
  }


  // LED LIGHT // 
  if (accel.readz() <= 275) //Accelerometer boundries for LED light position
  {
    showled:
    digitalWrite(ledPin, HIGH);//set LED pin high to turn on LED
    display.display();
    display.clearDisplay();
  }

}



//Draw rectangle on OLED
void testdrawrect(void) {
    display.drawRect(0, 35, 32, 93, WHITE);
    display.drawRect(0, 0, 32, 34, WHITE); 
    display.display();
    delay(1);
}

//Fill rectangle on OLED
void testfillrect(void) {
    display.fillRect(0, 0, 32, 34, WHITE);
    display.display();
    delay(1);
}
